# Statuses
OK = 0
INVALID_HANDLE = 1
DEVICE_NOT_FOUND = 2
DEVICE_NOT_OPENED = 3
IO_ERROR = 4
INSUFFICIENT_RESOURCES = 5
INVALID_PARAMETER = 6
INVALID_BAUD_RATE = 7
DEVICE_NOT_OPENED_FOR_ERASE = 8
DEVICE_NOT_OPENED_FOR_WRITE = 9
FAILED_TO_WRITE_DEVICE = 10
EEPROM_READ_FAILED = 11
EEPROM_WRITE_FAILED = 12
EEPROM_ERASE_FAILED = 13
EEPROM_NOT_PRESENT = 14
EEPROM_NOT_PROGRAMMED = 15
INVALID_ARGS = 16
NOT_SUPPORTED = 17
OTHER_ERROR = 18

# List Devices flags
LIST_NUMBER_ONLY = 0x80000000
LIST_BY_INDEX = 0x40000000
LIST_ALL = 0x20000000

# OpenEx flags
OPEN_BY_SERIAL_NUMBER = 1
OPEN_BY_DESCRIPTION = 2
OPEN_BY_LOCATION = 4

# Device Identifiers
DEVICE_232BM = 0
DEVICE_232AM = 1
DEVICE_100AX = 2
DEVICE_UNKNOWN = 3
DEVICE_2232C = 4
DEVICE_232R = 5
DEVICE_2232H = 6
DEVICE_4232H = 7
DEVICE_232H = 8
DEVICE_X_SERIES = 9

# Driver Types
DRIVER_TYPE_D2XX = 0
DRIVER_TYPE_VCP = 1

# Word Lengths
BITS_8 = 8
BITS_7 = 7

# Stop Bits
STOP_BITS_1 = 0
STOP_BITS_2 = 2

# Parity
PARITY_NONE = 0
PARITY_ODD = 1
PARITY_EVEN = 2
PARITY_MARK = 3
PARITY_SPACE = 4

# Flow Control
FLOW_NONE = 0x0000
FLOW_RTS_CTS = 0x0100
FLOW_DTR_DSR = 0x0200
FLOW_XON_XOFF = 0x0400

# Purge RX and TX Buffers
PURGE_RX = 1
PURGE_TX = 2

# Notification Events
EVENT_RXCHAR = 1
EVENT_MODEM_STATUS = 2
EVENT_LINE_STATUS = 4

MAX_DESCRIPTION_SIZE = 256



from setuptools import setup, find_packages
import subprocess
import sys

if sys.version_info >= (3, 0):
    try:
        from distutils.command.build_py import build_py_2to3 as build_py
        from distutils.command.build_scripts import build_scripts_2to3 as build_scripts
    except ImportError:
        raise ImportError("build_py_2to3 not found in distutils - it is required for Python 3.x")
    suffix = "-py3k"
else:
    from distutils.command.build_py import build_py
    from distutils.command.build_scripts import build_scripts
    suffix = ""


# import os
# mydir = os.path.dirname(__file__)
#
# if os.path.exists(os.path.join(mydir, '.bzr')):
#
#     from bzrlib.branch import Branch
#     branch = Branch.open_containing('.')[0]
#     revno = branch.revno()
#     revid = branch.get_rev_id(revno)
#     rtagdict  = branch.tags.get_reverse_tag_dict()
#     if revid in rtagdict:
#         version = rtagdict[revid][0]
#     else:
#         version = 'bzr%s' % revno
#     f = open(os.path.join(mydir, 'myversion.txt'), 'w')
#     print >> f, "version = %s" % version
#     f.close()
# else:
#     version = open(os.path.join(mydir, 'myversion.txt'), 'rU').read().strip()

with open('README.rst') as f:
    long_description = f.read()

setup(
    name="ftd2xx" + suffix,
    version=1.0,
    packages=find_packages(),
    # metadata for upload to PyPI
    author="Krishna Sudhakar",
    author_email="me@krishnasudhakar.me",
    description="Python interface to ftd2xx.dll from FTDI using ctypes based on d2xx by Pablo Bleyer",
    license="BSD",
    keywords="ftd2xx d2xx ftdi",
    url='https://github.com/ctrl-shift-esc/ftd2xx',  # project home page, if any
    zip_safe=False,
    test_suite="ftd2xx.tests.t_ftd2xx",
    long_description=long_description,
    cmdclass = {'build_py': build_py, 'build_scripts': build_scripts},
    # could also include long_description, download_url, classifiers, etc.
)
